CaptureEntirePageScreenshotToStringCommand (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.commands
Class CaptureEntirePageScreenshotToStringCommand

    java.lang.Object
      org.openqa.selenium.server.commands.Command
          org.openqa.selenium.server.commands.CaptureEntirePageScreenshotToStringCommand

    public class CaptureEntirePageScreenshotToStringCommand

extends Command

Capture a screenshot of the in-browser canvas. The entire web page is rendered not just the current viewport. Only works for Firefox in Chrome mode for now. Return a base 64 encoded PNG screenshot of of current page.

Field Summary
`static java.lang.String` | `ID`

Constructor Summary
`CaptureEntirePageScreenshotToStringCommand(java.lang.String kwargs, java.lang.String sessionId)`

Method Summary
`java.lang.String` | `capturePageScreenshot(java.lang.String filePath)`
`java.lang.String` | `execute()` Capture a screenshot of the in-browser canvas.
`java.io.File` | `screenshotDirectory()`
`java.lang.String` | `screenshotFilePath()`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Field Detail

### ID

    public static final java.lang.String ID

See Also:
  Constant Field Values

Constructor Detail

### CaptureEntirePageScreenshotToStringCommand

    public CaptureEntirePageScreenshotToStringCommand(java.lang.String kwargs,
                                                      java.lang.String sessionId)

Method Detail

### execute

    public java.lang.String execute()

  Capture a screenshot of the in-browser canvas. The entire web page is rendered not just the current viewport.

  Specified by:
    `execute` in class `Command`
  Returns:
    a base 64 encoded PNG screenshot of of current page.

### capturePageScreenshot

    public java.lang.String capturePageScreenshot(java.lang.String filePath)

### screenshotFilePath

    public java.lang.String screenshotFilePath()

### screenshotDirectory

    public java.io.File screenshotDirectory()

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.